
### Set the environment -------------------------

library("tidyr")
library("tidyverse")
library("dplyr")

library("stringr")
library("ggplot2")
library("reshape2")
library("Hmisc")
library("RColorBrewer")

library("lattice")
library("gplots")

Threshold <- 0.01

### Prepare every function that you need --------------------

setwd("N://Alfonso_Gomez//1 - Experimental Procedures//200606_Nocodazole_delivery//CellProfAnalys")

Nuclear_virus <- read.csv2("200606_Nocodazole_EdC_delivery_Maskedvirus.csv", header = T, sep = ",")

Masked_genome <- read.csv2("200606_Nocodazole_EdC_delivery_MaskGenome.csv", header = T, sep = ",")

##Set your treatments and your times

library("stringr")

add_my_numbers1 <- function(data){
  a <- str_split_fixed(data$Metadata_sample,"_",n = 6)
  V <- a[,4]
  Trt <- a[,5]
  Tim <- as.numeric(a[,6])
  data <- cbind(data,"Virus" =V, "Drug"= Trt, "Time"= Tim)
  return(data)
}

Con_time <- add_my_numbers1(Nuclear_virus)
Con_time_gen <- add_my_numbers1(Masked_genome)

## Convert those treatments into numbers so the analysis will be easier

Con_time$Virus <- gsub("Mock","0", Con_time$Virus)
Con_time$Virus <- gsub("wt","1", Con_time$Virus)
Con_time$Virus <- gsub("dV","2", Con_time$Virus)
Con_time$Virus <- as.numeric(Con_time$Virus)

Con_time$Drug <- gsub("Mock","0", Con_time$Drug)
Con_time$Drug <- gsub("Noc","1", Con_time$Drug)
Con_time$Drug <- as.numeric(Con_time$Drug)

Con_time$Time <- gsub("180","2", Con_time$Time)
Con_time$Time <- gsub("30","1", Con_time$Time)
Con_time$Time <- as.numeric(Con_time$Time)



Con_time_gen$Virus <- gsub("Mock","0", Con_time_gen$Virus)
Con_time_gen$Virus <- gsub("wt","1", Con_time_gen$Virus)
Con_time_gen$Virus <- gsub("dV","2", Con_time_gen$Virus)
Con_time_gen$Virus <- as.numeric(Con_time_gen$Virus)

Con_time_gen$Drug <- gsub("Mock","0", Con_time_gen$Drug)
Con_time_gen$Drug <- gsub("Noc","1", Con_time_gen$Drug)
Con_time_gen$Drug <- as.numeric(Con_time_gen$Drug)

Con_time_gen$Time <- gsub("180","2", Con_time_gen$Time)
Con_time_gen$Time <- gsub("30","1", Con_time_gen$Time)
Con_time_gen$Time <- as.numeric(Con_time_gen$Time)

######
## Now its time to count the viruses (Pos, Neg,...)
######
## First transform the columns of the signals into numbers (not characters)

as.numeric.factor <- function(x){
  as.numeric(levels(x))[x]
}

Con_time$Intensity_MeanIntensity_Hex <- as.numeric.factor(Con_time$Intensity_MeanIntensity_Hex)
Con_time$Intensity_MeanIntensity_EdC <- as.numeric.factor(Con_time$Intensity_MeanIntensity_EdC)

Con_time_gen$Intensity_MeanIntensity_Hex <- as.numeric.factor(Con_time_gen$Intensity_MeanIntensity_Hex)
Con_time_gen$Intensity_MeanIntensity_EdC <- as.numeric.factor(Con_time_gen$Intensity_MeanIntensity_EdC)

## Time for the experiment
#Count the amount of virus particles per cell as well as the amount of positive pVI VP

back_cap <- subset(Con_time, Con_time$Virus == 0)
back_cap <- subset(Con_time, Con_time$Virus == 1 & Con_time$Drug == 0 & Con_time$Time == 2)

back_cap_back <- back_cap[which(back_cap$Intensity_MeanIntensity_EdC >= 0.04),]

back_gen <- subset(Con_time_gen, Con_time_gen$Virus == 0)
back_gen <- subset(Con_time_gen, Con_time_gen$Virus == 1 & Con_time_gen$Drug == 0 & Con_time_gen$Time == 2)

back_gen_back <- back_gen[which(back_gen$Intensity_MeanIntensity_Hex >= 0.02),]

#####
##### Export all the raw intensities in an ordered manner
#####

genome <- as.data.frame(cbind('EdC' = Con_time_gen$Intensity_MeanIntensity_EdC, '9C12'=Con_time_gen$Intensity_MeanIntensity_Hex, 
                              'Nucleus'=Con_time_gen$Parent_Nuclus,'Drug' =Con_time_gen$Drug,
                              'Virus'=Con_time_gen$Virus, 'Time'=Con_time_gen$Time))

Virus <- as.data.frame(cbind( '9C12'=Con_time$Intensity_MeanIntensity_Hex, 'EdC' = Con_time$Intensity_MeanIntensity_EdC, 
                              'Nucleus'=Con_time$Parent_Nuclus,'Drug' =Con_time$Drug,
                              'Virus'=Con_time$Virus, 'Time'=Con_time$Time))

make_my_table <- function(exp) {
  for (Vi in 1:2){
    for (Ti in 1:2){
      for (tr in 0:1){
        clust <- subset(exp, (exp$Drug == tr) & (exp$Virus == Vi) & (exp$Time == Ti))
        output <- rbind(output, clust)
      }
    }
  }
  return(output)
}

output <- matrix(nrow = 0, ncol = 6)

genome2 <- make_my_table(genome)
write.csv2(genome2, file = "genome2.csv")

Virus2 <- make_my_table(Virus)
write.csv2(Virus2, file = "Virus2.csv")

### Prepare every function that you need --------------------

Split <- str_split_fixed(samp,"_",n = strng-2)

as.numeric.factor <- function(x){
  as.numeric(levels(x))[x]
}

New_genome_counting <- function(exp,strng,thres){
  output2 <- matrix(nrow = 0, ncol = 14)
  exp_size <- unique(exp$Metadata_sample, incomparables = FALSE)
  for (f in seq_along(exp_size)){
    samp <- as.character(exp_size[f])
    Split <- str_split_fixed(samp,"_",n = strng)
    Virus <- Split[,4]
    Drug <- Split[,5]
    sec_spl <- str_split_fixed(samp,"_",n = strng-2)
    good_samp <- sec_spl[,4]
    Time <- as.numeric(Split[,6])
    sample_matrix <- exp[exp$Metadata_sample== samp,]
    sites <- unique(sample_matrix$Metadata_Site, incomparables = FALSE)
    for (sit in seq_along(sites)){
      place <- as.character(sites[sit])
      ce <- subset(sample_matrix, (sample_matrix$Metadata_Site == place))
      ncel <- max(ce$Parent_Cell, na.rm = T)
      if (ncel==-Inf){
        output2 <- output2
      } else {
        for (c in 1:ncel){
          Genomes <- length(ce[ce[,"Parent_Cell"] == c,][,1])
          FreeNomes <- dim(ce[(ce$Intensity_MeanIntensity_Hex < thres) & (ce$Parent_Cell == c),])[1]
          Nucleus <- length(ce[ce[,"Parent_Nuclus"] == c,][,1])
          FreeNucleus <- dim(ce[(ce$Intensity_MeanIntensity_Hex < thres) & (ce$Parent_Nuclus == c),])[1]
          if (Genomes == 0){
            PercentFree <- 0
            PercentFreeNuc_rel <- 0
            PercentFreeNuc_abs <- 0
            PercentFreeCyt_rel <- 0
            PercentFreeCyt_abs <- 0
          } else {
            PercentFree <- (FreeNomes/Genomes)*100
            PercentFreeNuc_rel <- (FreeNucleus/FreeNomes)*100
            PercentFreeNuc_abs <- (FreeNucleus/Genomes)*100
            PercentFreeCyt_rel <- ((FreeNomes-FreeNucleus)/FreeNomes)*100
            PercentFreeCyt_abs <- ((FreeNomes-FreeNucleus)/Genomes)*100
          }
          output2 <- rbind(output2,c(good_samp, Virus, Drug, Time, c, Genomes,FreeNomes, 
                                     Nucleus,FreeNucleus,PercentFree, 
                                     PercentFreeNuc_rel,PercentFreeCyt_rel, 
                                     PercentFreeNuc_abs, PercentFreeCyt_abs))
        }
      }
    }
  }
  colnames(output2) <- c("Sample","Virus","Drug","Time","Cell", "Genomes", "Free_Genomes",
                         "Nuc_Gen","Free_Nuc_Gen","Percent_Free",
                         "Percent_Free_Nuc_rel", "Percent_Free_cyt_rel",
                         "Percent_Free_Nuc_abs", "Percent_Free_cyt_abs")
  output2 <- as.data.frame(output2)
  output2$Time <- as.numeric.factor(output2$Time)
  output2$Cell <- as.numeric.factor(output2$Cell)
  output2$Genomes <- as.numeric.factor(output2$Genomes)
  output2$Free_Genomes <- as.numeric.factor(output2$Free_Genomes)
  output2$Nuc_Gen <- as.numeric.factor(output2$Nuc_Gen)
  output2$Free_Nuc_Gen <- as.numeric.factor(output2$Free_Nuc_Gen)
  output2$Percent_Free <- as.numeric.factor(output2$Percent_Free)
  output2$Percent_Free_Nuc_rel <- as.numeric.factor(output2$Percent_Free_Nuc_rel)
  output2$Percent_Free_cyt_rel <- as.numeric.factor(output2$Percent_Free_cyt_rel)
  output2$Percent_Free_Nuc_abs <- as.numeric.factor(output2$Percent_Free_Nuc_abs)
  output2$Percent_Free_cyt_abs <- as.numeric.factor(output2$Percent_Free_cyt_abs)
  return(output2)
}


### New sample -------------------------------

setwd("N://Alfonso_Gomez//1 - Experimental Procedures//200606_Nocodazole_delivery//CellProfAnalys")

Nuclear_virus <- read.csv2("200606_Nocodazole_EdC_delivery_Maskedvirus.csv", header = T, sep = ",")

Masked_genome <- read.csv2("200606_Nocodazole_EdC_delivery_MaskGenome.csv", header = T, sep = ",")

Masked_genome$Intensity_MeanIntensity_Hex <- as.numeric.factor(Masked_genome$Intensity_MeanIntensity_Hex)
Masked_genome$Intensity_MeanIntensity_EdC <- as.numeric.factor(Masked_genome$Intensity_MeanIntensity_EdC)

Following_patterns <- unique(Masked_genome$Metadata_sample, incomparables = FALSE)
print(Following_patterns)

### Measure your sample --------------------------------

# You should input into the function 
# The data frame containing your data
# The number of splits "_" depeding on the sample name for teh regular expression
# The theshold that you want to set into the hexon

Gencount <- New_genome_counting(Masked_genome, 6,0.01)

### Subset your viruses and treatments -----------------

wt <- subset(Gencount, (Gencount$Sample == "wt_Mock_30") | 
               (Gencount$Sample == "wt_Mock_180") |
               (Gencount$Sample == "wt_Noc_180"))

dV <- subset(Gencount, (Gencount$Sample == "dV_Mock_30") | 
               (Gencount$Sample == "dV_Mock_180") |
               (Gencount$Sample == "dV_Noc_180"))

wt_2 <- subset(Gencount, (Gencount$Sample == "wt_Mock_30") | 
                 (Gencount$Sample == "wt_Noc_30") | 
                 (Gencount$Sample == "wt_Mock_180") | 
                 (Gencount$Sample == "wt_Noc_180"))

dV_2 <- subset(Gencount, (Gencount$Sample == "dV_Mock_30") | 
                 (Gencount$Sample == "dV_Noc_30") | 
                 (Gencount$Sample == "dV_Mock_180") | 
                 (Gencount$Sample == "dV_Noc_180"))

### Time for some graphs ------------------------------
# Set the order within your graphs

Combined_virus <- rbind(wt, dV)
Combined_virus$Sample <- factor(Combined_virus$Sample,
                                levels = c("wt_Mock_30","wt_Mock_180","wt_Noc_180",
                                           "dV_Mock_30","dV_Mock_180","dV_Noc_180"))
Combined_virus_2 <- rbind(wt_2, dV_2)
Combined_virus_2$Sample <- factor(Combined_virus_2$Sample,
                                  levels = c("wt_Mock_30","wt_Noc_30","wt_Mock_180","wt_Noc_180",
                                             "dV_Mock_30","dV_Noc_30","dV_Mock_180","dV_Noc_180"))


# Do the ggplots
ggplot(data = Combined_virus, aes(x = Sample, y = Percent_Free,
                                  color=Percent_Free_Nuc_rel, shape=Virus))+
  geom_point(binaxis='y', stackdir='center', stackratio=5,
             size = 2, alpha=0.8, position = position_jitter(width = 0.17))+
  scale_shape_manual(values=c(17, 19)) +
  scale_color_gradient2(midpoint= 50, low="red", mid="gray83", high="blue") +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="errorbar", color="black", width=0.2) +
  stat_summary(fun.y=mean, geom="point",shape= 19, color="black", width=0.2) +
  ylab("      Viral genomes
       devoid of capsid (%)") +
  ylim(0,100) +
  theme(axis.title = element_blank(),
        axis.title.x = element_blank()) +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1, colour = 'black'), axis.ticks = element_line(colour = 'black'))+
  theme(axis.text.y = element_text(colour = 'black'))

ggplot(data = Combined_virus_2, aes(x = Sample, y = Percent_Free,
                                    color=Percent_Free_Nuc_rel, shape=Virus))+
  geom_point(binaxis='y', stackdir='center', stackratio=5,
             size = 2, alpha=0.8, position = position_jitter(width = 0.17))+
  scale_shape_manual(values=c(17, 19)) +
  scale_color_gradient2(midpoint= 50, low="red", mid="gray83", high="blue") +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="errorbar", color="black", width=0.2) +
  stat_summary(fun.y=mean, geom="point",shape= 19, color="black", width=0.2) +
  ylab("      Viral genomes
       devoid of capsid (%)") +
  ylim(0,100) +
  theme(axis.title = element_blank(),
        axis.title.x = element_blank()) +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1, colour = 'black'), axis.ticks = element_line(colour = 'black'))+
  theme(axis.text.y = element_text(colour = 'black'))

ggplot(data = Combined_virus,aes(x = Sample,y = Percent_Free_Nuc_abs))+
  geom_point(binaxis='y', stackdir='center', stackratio=5,
             size = 2, alpha=0.8, position = position_jitter(width = 0.17))+
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  ylab("Virus particles per cell") +
  xlab("Well") +
  ylim(0, 100) +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1))


write.csv2(Gencount, file = "200608_Nocodazole_delivery_absolute.csv")

output2 <- matrix(nrow = 0, ncol = 11)

cell_counting <- function(exp){
  for (v in 1:2){
    for (i in 1:2){
      for (fr in 0:1){
        g <- subset(exp, (exp$Virus == v) & (exp$Drug == fr) & (exp$Time == i))
        msite <- max(g$Metadata_Site, na.rm = T)
        for (k in 0:11){
          p <- subset(g,(g$Metadata_Site == k))
          ncel <- max(p$Parent_Cell, na.rm = T)
          if (ncel == -Inf){
            output2 <- output2
          } else {
            for (c in 1:ncel){
              cells <- length(p[p[,"Parent_Cell"] == c,][,1])
              nucleus <- length(p[p[,"Parent_Nuclus"] == c,][,1])
              genomes <- dim(p[(p$Intensity_MeanIntensity_EdC < 0.04) & (p$Parent_Cell == c),])[1]
              percent <- (nucleus/cells)*100
              percentFree <- (genomes/cells)*100
              code <- v * 100 + i * 10 + fr
              output2 <- rbind(output2,c(v, fr, i, code, k, c, cells, nucleus,genomes,percent,percentFree))
            }
          }
        }
      }
    }
  }
  return(output2)
}

EndEsc_cellcount <- cell_counting(Con_time)
colnames(EndEsc_cellcount) <- c("Virus", "Drug", "Time","Code","Site", "Cell", "Virus_particles","Virus_in_nucleus","VirusFree","Percent","PercentFree")

EndEsc_cellcount <- as.data.frame(EndEsc_cellcount)

EndEsc_cellcount$Code <- gsub("110","wt_Mock_30min", EndEsc_cellcount$Code)
EndEsc_cellcount$Code <- gsub("120","wt_Mock_180min", EndEsc_cellcount$Code)
EndEsc_cellcount$Code <- gsub("111","wt_Noc_30min", EndEsc_cellcount$Code)
EndEsc_cellcount$Code <- gsub("121","wt_Noc_180min", EndEsc_cellcount$Code)

EndEsc_cellcount$Code <- gsub("210","dV_Mock_30min", EndEsc_cellcount$Code)
EndEsc_cellcount$Code <- gsub("220","dV_Mock_180min", EndEsc_cellcount$Code)
EndEsc_cellcount$Code <- gsub("211","dV_Noc_30min", EndEsc_cellcount$Code)
EndEsc_cellcount$Code <- gsub("221","dV_Noc_180min", EndEsc_cellcount$Code)

EndEsc_cellcount$Code <- gsub("3","Mock_Mock_20min", EndEsc_cellcount$Code)

ggplot(data = EndEsc_cellcount,aes(x = Code,y = Virus_particles))+
  geom_boxplot(color = "black") +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  ylab("Virus particles per cell") +
  xlab("Well") +
  ylim(0, 130) +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1))

ggplot(data = EndEsc_cellcount,aes(x = Code,y = Virus_in_nucleus))+
  geom_boxplot(color = "black") +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  ylab("Virus particles per cell") +
  xlab("Well") +
  ylim(0, 100) +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1))
